@@ -14,11 +14,6 @@ extern "C" {
 
 R_LIB_VERSION_HEADER (r_bin);
 
-#define R_BIN_SCN_EXECUTABLE (1 << 0)
-#define R_BIN_SCN_WRITABLE   (1 << 1)
-#define R_BIN_SCN_READABLE   (1 << 2)
-#define R_BIN_SCN_SHAREABLE  (1 << 3)
-
 #define R_BIN_DBG_STRIPPED 0x01
 #define R_BIN_DBG_STATIC   0x02
 #define R_BIN_DBG_LINENUMS 0x04
@@ -204,6 +199,7 @@ typedef struct r_bin_info_t {
 	int has_pi; // pic/pie
 	int has_canary;
 	int has_retguard;
+	int has_sanitizers;
 	int has_crypto;
 	int has_nx;
 	int big_endian;
@@ -444,7 +440,7 @@ typedef struct r_bin_section_t {
 	ut64 vsize;
 	ut64 vaddr;
 	ut64 paddr;
-	ut32 srwx;
+	ut32 perm;
 	// per section platform info
 	const char *arch;
 	char *format;
@@ -679,6 +675,9 @@ R_API RBinFile *r_bin_file_xtr_load_bytes(RBin *bin, RBinXtrPlugin *xtr, const c
 R_API bool r_bin_file_set_bytes(RBinFile *binfile, const ut8 *bytes, ut64 sz, bool steal_ptr);
 R_API RBinPlugin *r_bin_file_cur_plugin(RBinFile *binfile);
 
+/* section */
+R_API void r_bin_section_free(RBinSection *bs);
+
 /* obj.c */
 R_API void r_bin_object_free(void /*RBinObject*/ *o_);
 R_API ut64 r_bin_object_get_baddr(RBinObject *o);
@@ -824,6 +823,7 @@ R_API void r_bin_filter_sections (RList *list);
 R_API void r_bin_filter_classes (RList *list);
 R_API bool r_bin_strpurge(RBin *bin, const char *str, ut64 addr);
 R_API bool r_bin_string_filter(RBin *bin, const char *str, ut64 addr);
+R_API bool r_bin_is_cxx(RBinFile *binfile);
 
 /* plugin pointers */
 extern RBinPlugin r_bin_plugin_any;
